@@ -53,13 +53,14 @@ enum {
 
 typedef struct {
 	char *name;
+	char *cname;
 	char *comment;
-	GdkPixbuf *pixbuf;
+	char *icon;
 	char *bugzilla;
 	char *product;
 	char *component;
 	char *version;
-	char *email;
+	char *extra_info_script;
 } BugzillaApplication;
 
 struct _GnomeVersionInfo {
@@ -79,6 +80,7 @@ gboolean	   bugzilla_search_for_package (gpointer key, gpointer value, const cha
 SoupXmlrpcMessage* bugzilla_create_report  (BugzillaApplication *app, 
                                             GnomeVersionInfo *gnome_version,
                                             const char *username,
+                                            const char *title,
                                             const char *text,
                                             GladeXML *xml,
                                             GError **err);
